@@ -22,7 +22,13 @@ batch_register_embeddings_provider(
 )
 
 
-@pytest.fixture(params=["dashscope:text-embedding-v4", "siliconflow:BAAI/bge-m3"])
+@pytest.fixture(
+    params=[
+        "dashscope:text-embedding-v4",
+        "siliconflow:BAAI/bge-m3",
+        "ollama:bge-m3:latest",
+    ]
+)
 def embbeding_model(request: pytest.FixtureRequest) -> Embeddings:
     params = request.param
     return load_embeddings(params)
